# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: casing_inner_class.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "Test",
    "TestInnerClass",
)


from pydantic.dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto.Message):
    """ """

    inner: "TestInnerClass" = betterproto.message_field(2)
    """
    
    """


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class TestInnerClass(betterproto.Message):
    """ """

    old_exp: int = betterproto.sint32_field(1)
    """
    
    """



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: casing_message_field_uppercase.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from dataclasses import dataclass

import betterproto_fw


@dataclass(eq=False, repr=False)
class Test(betterproto_fw.Message):
    """ """

    uppercase: int = betterproto_fw.int32_field(1)
    """
    
    """

    uppercase_v2: int = betterproto_fw.int32_field(2)
    """
    
    """

    upper_camel_case: int = betterproto_fw.int32_field(3)
    """
    
    """



import abc
from collections import defaultdict
from dataclasses import (
    dataclass,
    field,
)
from typing import (
    Dict,
    Iterator,
    Optional,
    Set,
)


class TypingCompiler(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def optional(self, type: str) -> str:
        raise NotImplementedError()

    @abc.abstractmethod
    def list(self, type: str) -> str:
        raise NotImplementedError()

    @abc.abstractmethod
    def dict(self, key: str, value: str) -> str:
        raise NotImplementedError()

    @abc.abstractmethod
    def union(self, *types: str) -> str:
        raise NotImplementedError()

    @abc.abstractmethod
    def iterable(self, type: str) -> str:
        raise NotImplementedError()

    @abc.abstractmethod
    def async_iterable(self, type: str) -> str:
        raise NotImplementedError()

    @abc.abstractmethod
    def async_iterator(self, type: str) -> str:
        raise NotImplementedError()

    @abc.abstractmethod
    def imports(self) -> Dict[str, Optional[Set[str]]]:
        """
        Returns either the direct import as a key with none as value, or a set of
        values to import from the key.
        """
        raise NotImplementedError()

    def import_lines(self) -> Iterator:
        imports = self.imports()
        for key, value in imports.items():
            if value is None:
                yield f"import {key}"
            else:
                yield f"from {key} import ("
                for v in sorted(value):
                    yield f"    {v},"
                yield ")"


@dataclass
class DirectImportTypingCompiler(TypingCompiler):
    _imports: Dict[str, Set[str]] = field(default_factory=lambda: defaultdict(set))

    def optional(self, type: str) -> str:
        self._imports["typing"].add("Optional")
        return f"Optional[{type}]"

    def list(self, type: str) -> str:
        self._imports["typing"].add("List")
        return f"List[{type}]"

    def dict(self, key: str, value: str) -> str:
        self._imports["typing"].add("Dict")
        return f"Dict[{key}, {value}]"

    def union(self, *types: str) -> str:
        self._imports["typing"].add("Union")
        return f"Union[{', '.join(types)}]"

    def iterable(self, type: str) -> str:
        self._imports["typing"].add("Iterable")
        return f"Iterable[{type}]"

    def async_iterable(self, type: str) -> str:
        self._imports["typing"].add("AsyncIterable")
        return f"AsyncIterable[{type}]"

    def async_iterator(self, type: str) -> str:
        self._imports["typing"].add("AsyncIterator")
        return f"AsyncIterator[{type}]"

    def imports(self) -> Dict[str, Optional[Set[str]]]:
        return {k: v if v else None for k, v in self._imports.items()}


@dataclass
class TypingImportTypingCompiler(TypingCompiler):
    _imported: bool = False

    def optional(self, type: str) -> str:
        self._imported = True
        return f"typing.Optional[{type}]"

    def list(self, type: str) -> str:
        self._imported = True
        return f"typing.List[{type}]"

    def dict(self, key: str, value: str) -> str:
        self._imported = True
        return f"typing.Dict[{key}, {value}]"

    def union(self, *types: str) -> str:
        self._imported = True
        return f"typing.Union[{', '.join(types)}]"

    def iterable(self, type: str) -> str:
        self._imported = True
        return f"typing.Iterable[{type}]"

    def async_iterable(self, type: str) -> str:
        self._imported = True
        return f"typing.AsyncIterable[{type}]"

    def async_iterator(self, type: str) -> str:
        self._imported = True
        return f"typing.AsyncIterator[{type}]"

    def imports(self) -> Dict[str, Optional[Set[str]]]:
        if self._imported:
            return {"typing": None}
        return {}


@dataclass
class NoTyping310TypingCompiler(TypingCompiler):
    _imports: Dict[str, Set[str]] = field(default_factory=lambda: defaultdict(set))

    @staticmethod
    def _fmt(type: str) -> str:  # for now this is necessary till 3.14
        if type.startswith('"'):
            return type[1:-1]
        return type

    def optional(self, type: str) -> str:
        return f'"{self._fmt(type)} | None"'

    def list(self, type: str) -> str:
        return f'"list[{self._fmt(type)}]"'

    def dict(self, key: str, value: str) -> str:
        return f'"dict[{key}, {self._fmt(value)}]"'

    def union(self, *types: str) -> str:
        return f'"{" | ".join(map(self._fmt, types))}"'

    def iterable(self, type: str) -> str:
        self._imports["collections.abc"].add("Iterable")
        return f'"Iterable[{type}]"'

    def async_iterable(self, type: str) -> str:
        self._imports["collections.abc"].add("AsyncIterable")
        return f'"AsyncIterable[{type}]"'

    def async_iterator(self, type: str) -> str:
        self._imports["collections.abc"].add("AsyncIterator")
        return f'"AsyncIterator[{type}]"'

    def imports(self) -> Dict[str, Optional[Set[str]]]:
        return {k: v if v else None for k, v in self._imports.items()}



def test_all_definition():
    """
    Check that a compiled module defines __all__ with the right value.

    These modules have been chosen since they contain messages, services and enums.
    """
    import tests.output_betterproto.enum as enum
    import tests.output_betterproto.service as service

    assert service.__all__ == (
        "ThingType",
        "DoThingRequest",
        "DoThingResponse",
        "GetThingRequest",
        "GetThingResponse",
        "TestStub",
        "TestBase",
    )
    assert enum.__all__ == ("Choice", "ArithmeticOperator", "Test")



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: oneof_enum.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'oneof_enum.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10oneof_enum.proto\x12\noneof_enum\"X\n\x04Test\x12$\n\x06signal\x18\x01 \x01(\x0e\x32\x12.oneof_enum.SignalH\x00\x12 \n\x04move\x18\x02 \x01(\x0b\x32\x10.oneof_enum.MoveH\x00\x42\x08\n\x06\x61\x63tion\"\x1c\n\x04Move\x12\t\n\x01x\x18\x01 \x01(\x05\x12\t\n\x01y\x18\x02 \x01(\x05*\x1e\n\x06Signal\x12\x08\n\x04PASS\x10\x00\x12\n\n\x06RESIGN\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'oneof_enum_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SIGNAL']._serialized_start=152
  _globals['_SIGNAL']._serialized_end=182
  _globals['_TEST']._serialized_start=32
  _globals['_TEST']._serialized_end=120
  _globals['_MOVE']._serialized_start=122
  _globals['_MOVE']._serialized_end=150
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: map.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'map.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tmap.proto\x12\x03map\"\\\n\x04Test\x12%\n\x06\x63ounts\x18\x01 \x03(\x0b\x32\x15.map.Test.CountsEntry\x1a-\n\x0b\x43ountsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'map_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TEST_COUNTSENTRY']._loaded_options = None
  _globals['_TEST_COUNTSENTRY']._serialized_options = b'8\001'
  _globals['_TEST']._serialized_start=18
  _globals['_TEST']._serialized_end=110
  _globals['_TEST_COUNTSENTRY']._serialized_start=65
  _globals['_TEST_COUNTSENTRY']._serialized_end=110
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: map.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from typing import (
    Dict,
)

from pydantic.dataclasses import dataclass

import betterproto_fw


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto_fw.Message):
    """ """

    counts: Dict[str, int] = betterproto_fw.map_field(
        1, betterproto_fw.TYPE_STRING, betterproto_fw.TYPE_INT32
    )
    """
    
    """



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: repeatedpacked.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from typing import (
    List,
)

from pydantic.dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto.Message):
    """ """

    counts: List[int] = betterproto.int32_field(1)
    """
    
    """

    signed: List[int] = betterproto.sint64_field(2)
    """
    
    """

    fixed: List[float] = betterproto.double_field(3)
    """
    
    """



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: import_child_package_from_root.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False)
class Test(betterproto.Message):
    """
    Tests generated imports when a message in root refers to a message in a child package.
    """

    child: "childpackage.Message" = betterproto.message_field(1)
    """
    
    """


from . import childpackage



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: example_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'example_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x65xample_service.proto\x12\x0f\x65xample_service\"A\n\x0e\x45xampleRequest\x12\x16\n\x0e\x65xample_string\x18\x01 \x01(\t\x12\x17\n\x0f\x65xample_integer\x18\x02 \x01(\x03\"B\n\x0f\x45xampleResponse\x12\x16\n\x0e\x65xample_string\x18\x01 \x01(\t\x12\x17\n\x0f\x65xample_integer\x18\x02 \x01(\x03\x32\xf2\x02\n\x04Test\x12V\n\x11\x45xampleUnaryUnary\x12\x1f.example_service.ExampleRequest\x1a .example_service.ExampleResponse\x12Y\n\x12\x45xampleUnaryStream\x12\x1f.example_service.ExampleRequest\x1a .example_service.ExampleResponse0\x01\x12Y\n\x12\x45xampleStreamUnary\x12\x1f.example_service.ExampleRequest\x1a .example_service.ExampleResponse(\x01\x12\\\n\x13\x45xampleStreamStream\x12\x1f.example_service.ExampleRequest\x1a .example_service.ExampleResponse(\x01\x30\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'example_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_EXAMPLEREQUEST']._serialized_start=42
  _globals['_EXAMPLEREQUEST']._serialized_end=107
  _globals['_EXAMPLERESPONSE']._serialized_start=109
  _globals['_EXAMPLERESPONSE']._serialized_end=175
  _globals['_TEST']._serialized_start=178
  _globals['_TEST']._serialized_end=548
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: package_message.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("PackageMessage",)


from dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False)
class PackageMessage(betterproto.Message):
    """ """

    c: "childpackage.ChildMessage" = betterproto.message_field(1)
    """
    
    """


from . import childpackage



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: field_name_identical_to_type.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)

import builtins

from pydantic.dataclasses import dataclass

import betterproto_fw


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto_fw.Message):
    """
    Tests that messages may contain fields with names that are identical to their python types (PR #294)
    """

    int: builtins.int = betterproto_fw.int32_field(1)
    """
    
    """

    float: builtins.float = betterproto_fw.float_field(2)
    """
    
    """

    str: builtins.str = betterproto_fw.string_field(3)
    """
    
    """

    bytes: builtins.bytes = betterproto_fw.bytes_field(4)
    """
    
    """

    bool: builtins.bool = betterproto_fw.bool_field(5)
    """
    
    """



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: proto3_field_presence_oneof.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "Test",
    "InnerNested",
    "Nested",
    "WithOptional",
)


from dataclasses import dataclass
from typing import (
    Optional,
)

import betterproto


@dataclass(eq=False, repr=False)
class Test(betterproto.Message):
    """ """

    nested: "Nested" = betterproto.message_field(1, group="kind")
    """
    
    """

    with_optional: "WithOptional" = betterproto.message_field(2, group="kind")
    """
    
    """


@dataclass(eq=False, repr=False)
class InnerNested(betterproto.Message):
    """ """

    a: Optional[bool] = betterproto.bool_field(1, optional=True)
    """
    
    """


@dataclass(eq=False, repr=False)
class Nested(betterproto.Message):
    """ """

    inner: "InnerNested" = betterproto.message_field(1)
    """
    
    """


@dataclass(eq=False, repr=False)
class WithOptional(betterproto.Message):
    """ """

    b: Optional[bool] = betterproto.bool_field(2, optional=True)
    """
    
    """



import tests.output_betterproto.casing_inner_class as casing_inner_class


def test_message_casing_inner_class_name():
    assert hasattr(casing_inner_class, "TestInnerClass"), (
        "Inline defined Message is correctly converted to CamelCase"
    )


def test_message_casing_inner_class_attributes():
    message = casing_inner_class.Test()
    assert hasattr(message.inner, "old_exp"), (
        "Inline defined Message attribute is snake_case"
    )



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: regression_414.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from typing import (
    List,
)

from pydantic.dataclasses import dataclass

import betterproto_fw


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto_fw.Message):
    """ """

    body: bytes = betterproto_fw.bytes_field(1)
    """
    
    """

    auth: bytes = betterproto_fw.bytes_field(2)
    """
    
    """

    signatures: List[bytes] = betterproto_fw.bytes_field(3)
    """
    
    """



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: other.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("OtherPackageMessage",)


from pydantic.dataclasses import dataclass

import betterproto_fw


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class OtherPackageMessage(betterproto_fw.Message):
    """ """

    root_package_message: "__import_circular_dependency__.RootPackageMessage" = (
        betterproto_fw.message_field(1)
    )
    """
    
    """


from ... import import_circular_dependency as __import_circular_dependency__



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: google_impl_behavior_equivalence.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'google_impl_behavior_equivalence.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&google_impl_behavior_equivalence.proto\x12 google_impl_behavior_equivalence\x1a\x1fgoogle/protobuf/timestamp.proto\"\x12\n\x03\x46oo\x12\x0b\n\x03\x62\x61r\x18\x01 \x01(\x03\"j\n\x04Test\x12\x10\n\x06string\x18\x01 \x01(\tH\x00\x12\x11\n\x07integer\x18\x02 \x01(\x03H\x00\x12\x34\n\x03\x66oo\x18\x03 \x01(\x0b\x32%.google_impl_behavior_equivalence.FooH\x00\x42\x07\n\x05group\".\n\x04Spam\x12&\n\x02ts\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"?\n\x07Request\x12\x34\n\x03\x66oo\x18\x01 \x01(\x0b\x32\'.google_impl_behavior_equivalence.Empty\"\x07\n\x05\x45mptyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google_impl_behavior_equivalence_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_FOO']._serialized_start=109
  _globals['_FOO']._serialized_end=127
  _globals['_TEST']._serialized_start=129
  _globals['_TEST']._serialized_end=235
  _globals['_SPAM']._serialized_start=237
  _globals['_SPAM']._serialized_end=283
  _globals['_REQUEST']._serialized_start=285
  _globals['_REQUEST']._serialized_end=348
  _globals['_EMPTY']._serialized_start=350
  _globals['_EMPTY']._serialized_end=357
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: import_service_input_message.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'import_service_input_message.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import request_message_pb2 as request__message__pb2
import child_package_request_message_pb2 as child__package__request__message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"import_service_input_message.proto\x12\x1cimport_service_input_message\x1a\x15request_message.proto\x1a#child_package_request_message.proto\" \n\x0fRequestResponse\x12\r\n\x05value\x18\x01 \x01(\x05\"2\n\x06Nested\x1a(\n\x0eRequestMessage\x12\x16\n\x0enestedArgument\x18\x01 \x01(\x05\x32\xd2\x02\n\x04Test\x12\x66\n\x07\x44oThing\x12,.import_service_input_message.RequestMessage\x1a-.import_service_input_message.RequestResponse\x12r\n\x08\x44oThing2\x12\x37.import_service_input_message.child.ChildRequestMessage\x1a-.import_service_input_message.RequestResponse\x12n\n\x08\x44oThing3\x12\x33.import_service_input_message.Nested.RequestMessage\x1a-.import_service_input_message.RequestResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'import_service_input_message_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_REQUESTRESPONSE']._serialized_start=128
  _globals['_REQUESTRESPONSE']._serialized_end=160
  _globals['_NESTED']._serialized_start=162
  _globals['_NESTED']._serialized_end=212
  _globals['_NESTED_REQUESTMESSAGE']._serialized_start=172
  _globals['_NESTED_REQUESTMESSAGE']._serialized_end=212
  _globals['_TEST']._serialized_start=215
  _globals['_TEST']._serialized_end=553
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: deprecated.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "Test",
    "Message",
    "Empty",
    "TestServiceStub",
    "TestServiceBase",
)

import warnings
from dataclasses import dataclass
from typing import (
    TYPE_CHECKING,
    Dict,
    Optional,
)

import grpclib

import betterproto
from betterproto.grpc.grpclib_server import ServiceBase


if TYPE_CHECKING:
    import grpclib.server
    from grpclib.metadata import Deadline

    from betterproto.grpc.grpclib_client import MetadataLike


@dataclass(eq=False, repr=False)
class Test(betterproto.Message):
    """Some documentation about the Test message."""

    message: "Message" = betterproto.message_field(1)
    """
    
    """

    value: int = betterproto.int32_field(2)
    """
    
    """

    def __post_init__(self) -> None:
        super().__post_init__()
        if self.is_set("message"):
            warnings.warn("Test.message is deprecated", DeprecationWarning)


@dataclass(eq=False, repr=False)
class Message(betterproto.Message):
    """ """

    value: str = betterproto.string_field(1)
    """
    
    """

    def __post_init__(self) -> None:
        warnings.warn("Message is deprecated", DeprecationWarning)
        super().__post_init__()


@dataclass(eq=False, repr=False)
class Empty(betterproto.Message):
    """ """

    pass


class TestServiceStub(betterproto.ServiceStub):
    """ """

    async def func(
        self,
        empty: "Empty",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "Empty":
        """ """

        return await self._unary_unary(
            "/deprecated.TestService/func",
            empty,
            Empty,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def deprecated_func(
        self,
        empty: "Empty",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "Empty":
        """ """

        warnings.warn("TestService.deprecated_func is deprecated", DeprecationWarning)

        return await self._unary_unary(
            "/deprecated.TestService/deprecated_func",
            empty,
            Empty,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )


class TestServiceBase(ServiceBase):
    """ """

    async def func(self, empty: "Empty") -> "Empty":
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def deprecated_func(self, empty: "Empty") -> "Empty":
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def __rpc_func(self, stream: "grpclib.server.Stream[Empty, Empty]") -> None:
        request = await stream.recv_message()
        response = await self.func(request)
        await stream.send_message(response)

    async def __rpc_deprecated_func(
        self, stream: "grpclib.server.Stream[Empty, Empty]"
    ) -> None:
        request = await stream.recv_message()
        response = await self.deprecated_func(request)
        await stream.send_message(response)

    def __mapping__(self) -> Dict[str, grpclib.const.Handler]:
        return {
            "/deprecated.TestService/func": grpclib.const.Handler(
                self.__rpc_func,
                grpclib.const.Cardinality.UNARY_UNARY,
                Empty,
                Empty,
            ),
            "/deprecated.TestService/deprecated_func": grpclib.const.Handler(
                self.__rpc_deprecated_func,
                grpclib.const.Cardinality.UNARY_UNARY,
                Empty,
                Empty,
            ),
        }



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: oneof.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "MixedDrink",
    "Test",
)


from dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False)
class MixedDrink(betterproto.Message):
    """ """

    shots: int = betterproto.int32_field(1)
    """
    
    """


@dataclass(eq=False, repr=False)
class Test(betterproto.Message):
    """ """

    pitied: int = betterproto.int32_field(1, group="foo")
    """
    
    """

    pitier: str = betterproto.string_field(2, group="foo")
    """
    
    """

    just_a_regular_field: int = betterproto.int32_field(3)
    """
    
    """

    drinks: int = betterproto.int32_field(11, group="bar")
    """
    
    """

    bar_name: str = betterproto.string_field(12, group="bar")
    """
    
    """

    mixed_drink: "MixedDrink" = betterproto.message_field(13, group="bar")
    """
    
    """



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nestedtwice.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'nestedtwice.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11nestedtwice.proto\x12\x0bnestedtwice\"\x96\x03\n\x04Test\x12\"\n\x03top\x18\x01 \x01(\x0b\x32\x15.nestedtwice.Test.Top\x1a\xe9\x02\n\x03Top\x12\x0c\n\x04name\x18\x01 \x01(\t\x12,\n\x06middle\x18\x02 \x01(\x0b\x32\x1c.nestedtwice.Test.Top.Middle\x1a\xa5\x02\n\x06Middle\x12\x33\n\x06\x62ottom\x18\x02 \x03(\x0b\x32#.nestedtwice.Test.Top.Middle.Bottom\x12;\n\nenumBottom\x18\x03 \x03(\x0e\x32\'.nestedtwice.Test.Top.Middle.EnumBottom\x12\x45\n\x0ftopMiddleBottom\x18\x04 \x03(\x0b\x32,.nestedtwice.Test.Top.Middle.TopMiddleBottom\x12\x0b\n\x03\x62\x61r\x18\x05 \x01(\x08\x1a\x1c\n\x0fTopMiddleBottom\x12\t\n\x01\x61\x18\x01 \x01(\t\x1a\x15\n\x06\x42ottom\x12\x0b\n\x03\x66oo\x18\x01 \x01(\t\"\x1a\n\nEnumBottom\x12\x05\n\x01\x41\x10\x00\x12\x05\n\x01\x42\x10\x01J\x04\x08\x01\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nestedtwice_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TEST']._serialized_start=35
  _globals['_TEST']._serialized_end=441
  _globals['_TEST_TOP']._serialized_start=80
  _globals['_TEST_TOP']._serialized_end=441
  _globals['_TEST_TOP_MIDDLE']._serialized_start=148
  _globals['_TEST_TOP_MIDDLE']._serialized_end=441
  _globals['_TEST_TOP_MIDDLE_TOPMIDDLEBOTTOM']._serialized_start=356
  _globals['_TEST_TOP_MIDDLE_TOPMIDDLEBOTTOM']._serialized_end=384
  _globals['_TEST_TOP_MIDDLE_BOTTOM']._serialized_start=386
  _globals['_TEST_TOP_MIDDLE_BOTTOM']._serialized_end=407
  _globals['_TEST_TOP_MIDDLE_ENUMBOTTOM']._serialized_start=409
  _globals['_TEST_TOP_MIDDLE_ENUMBOTTOM']._serialized_end=435
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: google_impl_behavior_equivalence.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "Foo",
    "Test",
    "Spam",
    "Request",
    "Empty",
)


from datetime import datetime
from typing import (
    Optional,
)

from pydantic import model_validator
from pydantic.dataclasses import dataclass

import betterproto_fw


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Foo(betterproto_fw.Message):
    """ """

    bar: int = betterproto_fw.int64_field(1)
    """
    
    """


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto_fw.Message):
    """ """

    string: Optional[str] = betterproto_fw.string_field(1, optional=True, group="group")
    """
    
    """

    integer: Optional[int] = betterproto_fw.int64_field(2, optional=True, group="group")
    """
    
    """

    foo: Optional["Foo"] = betterproto_fw.message_field(3, optional=True, group="group")
    """
    
    """

    @model_validator(mode="after")
    def check_oneof(cls, values):
        return cls._validate_field_groups(values)


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Spam(betterproto_fw.Message):
    """ """

    ts: datetime = betterproto_fw.message_field(1)
    """
    
    """


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Request(betterproto_fw.Message):
    """ """

    foo: "Empty" = betterproto_fw.message_field(1)
    """
    
    """


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Empty(betterproto_fw.Message):
    """ """

    pass



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: service.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "DoThingRequest",
    "DoThingResponse",
    "TestStub",
    "TestBase",
)


from dataclasses import dataclass
from typing import (
    TYPE_CHECKING,
    Dict,
    List,
    Optional,
)

import grpclib

import betterproto
from betterproto.grpc.grpclib_server import ServiceBase


if TYPE_CHECKING:
    import grpclib.server
    from grpclib.metadata import Deadline

    from betterproto.grpc.grpclib_client import MetadataLike


@dataclass(eq=False, repr=False)
class DoThingRequest(betterproto.Message):
    """ """

    name: str = betterproto.string_field(1)
    """
    
    """

    comments: List[str] = betterproto.string_field(2)
    """
    
    """


@dataclass(eq=False, repr=False)
class DoThingResponse(betterproto.Message):
    """ """

    names: List[str] = betterproto.string_field(1)
    """
    
    """


class TestStub(betterproto.ServiceStub):
    """ """

    async def do_thing(
        self,
        do_thing_request: "DoThingRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "DoThingResponse":
        """ """

        return await self._unary_unary(
            "/service_uppercase.Test/DoThing",
            do_thing_request,
            DoThingResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )


class TestBase(ServiceBase):
    """ """

    async def do_thing(self, do_thing_request: "DoThingRequest") -> "DoThingResponse":
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def __rpc_do_thing(
        self, stream: "grpclib.server.Stream[DoThingRequest, DoThingResponse]"
    ) -> None:
        request = await stream.recv_message()
        response = await self.do_thing(request)
        await stream.send_message(response)

    def __mapping__(self) -> Dict[str, grpclib.const.Handler]:
        return {
            "/service_uppercase.Test/DoThing": grpclib.const.Handler(
                self.__rpc_do_thing,
                grpclib.const.Cardinality.UNARY_UNARY,
                DoThingRequest,
                DoThingResponse,
            ),
        }



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rservice.proto\x12\x07service\"R\n\x0e\x44oThingRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x63omments\x18\x02 \x03(\t\x12 \n\x04type\x18\x03 \x01(\x0e\x32\x12.service.ThingType\" \n\x0f\x44oThingResponse\x12\r\n\x05names\x18\x01 \x03(\t\"\x1f\n\x0fGetThingRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"1\n\x10GetThingResponse\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x05*.\n\tThingType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06LIVING\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x32\xa3\x02\n\x04Test\x12<\n\x07\x44oThing\x12\x17.service.DoThingRequest\x1a\x18.service.DoThingResponse\x12\x43\n\x0c\x44oManyThings\x12\x17.service.DoThingRequest\x1a\x18.service.DoThingResponse(\x01\x12I\n\x10GetThingVersions\x12\x18.service.GetThingRequest\x1a\x19.service.GetThingResponse0\x01\x12M\n\x12GetDifferentThings\x12\x18.service.GetThingRequest\x1a\x19.service.GetThingResponse(\x01\x30\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_THINGTYPE']._serialized_start=228
  _globals['_THINGTYPE']._serialized_end=274
  _globals['_DOTHINGREQUEST']._serialized_start=26
  _globals['_DOTHINGREQUEST']._serialized_end=108
  _globals['_DOTHINGRESPONSE']._serialized_start=110
  _globals['_DOTHINGRESPONSE']._serialized_end=142
  _globals['_GETTHINGREQUEST']._serialized_start=144
  _globals['_GETTHINGREQUEST']._serialized_end=175
  _globals['_GETTHINGRESPONSE']._serialized_start=177
  _globals['_GETTHINGRESPONSE']._serialized_end=226
  _globals['_TEST']._serialized_start=277
  _globals['_TEST']._serialized_end=568
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: recursivemessage.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'recursivemessage.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16recursivemessage.proto\x12\x10recursivemessage\"q\n\x04Test\x12\x0c\n\x04name\x18\x01 \x01(\t\x12%\n\x05\x63hild\x18\x02 \x01(\x0b\x32\x16.recursivemessage.Test\x12\x34\n\x0cintermediate\x18\x03 \x01(\x0b\x32\x1e.recursivemessage.Intermediate\"E\n\x0cIntermediate\x12\x0e\n\x06number\x18\x01 \x01(\x05\x12%\n\x05\x63hild\x18\x02 \x01(\x0b\x32\x16.recursivemessage.Testb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'recursivemessage_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TEST']._serialized_start=44
  _globals['_TEST']._serialized_end=157
  _globals['_INTERMEDIATE']._serialized_start=159
  _globals['_INTERMEDIATE']._serialized_end=228
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: proto3_field_presence_oneof.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'proto3_field_presence_oneof.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!proto3_field_presence_oneof.proto\x12\x1bproto3_field_presence_oneof\"\x89\x01\n\x04Test\x12\x35\n\x06nested\x18\x01 \x01(\x0b\x32#.proto3_field_presence_oneof.NestedH\x00\x12\x42\n\rwith_optional\x18\x02 \x01(\x0b\x32).proto3_field_presence_oneof.WithOptionalH\x00\x42\x06\n\x04kind\"#\n\x0bInnerNested\x12\x0e\n\x01\x61\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\x04\n\x02_a\"A\n\x06Nested\x12\x37\n\x05inner\x18\x01 \x01(\x0b\x32(.proto3_field_presence_oneof.InnerNested\"$\n\x0cWithOptional\x12\x0e\n\x01\x62\x18\x02 \x01(\x08H\x00\x88\x01\x01\x42\x04\n\x02_bb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'proto3_field_presence_oneof_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TEST']._serialized_start=67
  _globals['_TEST']._serialized_end=204
  _globals['_INNERNESTED']._serialized_start=206
  _globals['_INNERNESTED']._serialized_end=241
  _globals['_NESTED']._serialized_start=243
  _globals['_NESTED']._serialized_end=308
  _globals['_WITHOPTIONAL']._serialized_start=310
  _globals['_WITHOPTIONAL']._serialized_end=346
# @@protoc_insertion_point(module_scope)



from tests.output_betterproto.casing_message_field_uppercase import Test


def test_message_casing():
    message = Test()
    assert hasattr(message, "uppercase"), (
        "UPPERCASE attribute is converted to 'uppercase' in python"
    )
    assert hasattr(message, "uppercase_v2"), (
        "UPPERCASE_V2 attribute is converted to 'uppercase_v2' in python"
    )
    assert hasattr(message, "upper_camel_case"), (
        "UPPER_CAMEL_CASE attribute is converted to upper_camel_case in python"
    )



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: import_circular_dependency.proto, root.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "RootPackageMessage",
    "Test",
)


from pydantic.dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class RootPackageMessage(betterproto.Message):
    """ """

    pass


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto.Message):
    """
    This test-case verifies support for circular dependencies in the generated python files.

    This is important because we generate 1 python file/module per package, rather than 1 file per proto file.

    Scenario:

        The proto messages depend on each other in a non-circular way:

              Test -------> RootPackageMessage <--------------.
                `------------------------------------> OtherPackageMessage

        Test and RootPackageMessage are in different files, but belong to the same package (root):

              (Test -------> RootPackageMessage) <------------.
                `------------------------------------> OtherPackageMessage

        After grouping the packages into single files or modules, a circular dependency is created:

              (root: Test & RootPackageMessage) <-------> (other: OtherPackageMessage)
    """

    message: "RootPackageMessage" = betterproto.message_field(1)
    """
    
    """

    other_value: "other.OtherPackageMessage" = betterproto.message_field(2)
    """
    
    """


from . import other



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: import_service_input_message.proto, request_message.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "RequestMessage",
    "RequestResponse",
    "Nested",
    "NestedRequestMessage",
    "TestStub",
    "TestBase",
)


from typing import (
    TYPE_CHECKING,
    Dict,
    Optional,
)

import grpclib
from pydantic.dataclasses import dataclass

import betterproto
from betterproto.grpc.grpclib_server import ServiceBase


if TYPE_CHECKING:
    import grpclib.server
    from grpclib.metadata import Deadline

    from betterproto.grpc.grpclib_client import MetadataLike


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class RequestMessage(betterproto.Message):
    """ """

    argument: int = betterproto.int32_field(1)
    """
    
    """


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class RequestResponse(betterproto.Message):
    """ """

    value: int = betterproto.int32_field(1)
    """
    
    """


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Nested(betterproto.Message):
    """ """

    pass


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class NestedRequestMessage(betterproto.Message):
    """ """

    nested_argument: int = betterproto.int32_field(1)
    """
    
    """


class TestStub(betterproto.ServiceStub):
    """Tests generated service correctly imports the RequestMessage"""

    async def do_thing(
        self,
        request_message: "RequestMessage",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "RequestResponse":
        """ """

        return await self._unary_unary(
            "/import_service_input_message.Test/DoThing",
            request_message,
            RequestResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def do_thing2(
        self,
        child_child_request_message: "child.ChildRequestMessage",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "RequestResponse":
        """ """

        return await self._unary_unary(
            "/import_service_input_message.Test/DoThing2",
            child_child_request_message,
            RequestResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def do_thing3(
        self,
        nested_request_message: "NestedRequestMessage",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "RequestResponse":
        """ """

        return await self._unary_unary(
            "/import_service_input_message.Test/DoThing3",
            nested_request_message,
            RequestResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )


from . import child


class TestBase(ServiceBase):
    """Tests generated service correctly imports the RequestMessage"""

    async def do_thing(self, request_message: "RequestMessage") -> "RequestResponse":
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def do_thing2(
        self, child_child_request_message: "child.ChildRequestMessage"
    ) -> "RequestResponse":
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def do_thing3(
        self, nested_request_message: "NestedRequestMessage"
    ) -> "RequestResponse":
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def __rpc_do_thing(
        self, stream: "grpclib.server.Stream[RequestMessage, RequestResponse]"
    ) -> None:
        request = await stream.recv_message()
        response = await self.do_thing(request)
        await stream.send_message(response)

    async def __rpc_do_thing2(
        self,
        stream: "grpclib.server.Stream[child.ChildRequestMessage, RequestResponse]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.do_thing2(request)
        await stream.send_message(response)

    async def __rpc_do_thing3(
        self, stream: "grpclib.server.Stream[NestedRequestMessage, RequestResponse]"
    ) -> None:
        request = await stream.recv_message()
        response = await self.do_thing3(request)
        await stream.send_message(response)

    def __mapping__(self) -> Dict[str, grpclib.const.Handler]:
        return {
            "/import_service_input_message.Test/DoThing": grpclib.const.Handler(
                self.__rpc_do_thing,
                grpclib.const.Cardinality.UNARY_UNARY,
                RequestMessage,
                RequestResponse,
            ),
            "/import_service_input_message.Test/DoThing2": grpclib.const.Handler(
                self.__rpc_do_thing2,
                grpclib.const.Cardinality.UNARY_UNARY,
                child.ChildRequestMessage,
                RequestResponse,
            ),
            "/import_service_input_message.Test/DoThing3": grpclib.const.Handler(
                self.__rpc_do_thing3,
                grpclib.const.Cardinality.UNARY_UNARY,
                NestedRequestMessage,
                RequestResponse,
            ),
        }



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: googletypes_response_embedded.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'googletypes_response_embedded.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#googletypes_response_embedded.proto\x12\x1dgoogletypes_response_embedded\x1a\x1egoogle/protobuf/wrappers.proto\"\x07\n\x05Input\"\xd0\x03\n\x06Output\x12\x32\n\x0c\x64ouble_value\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x30\n\x0b\x66loat_value\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x30\n\x0bint64_value\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x32\n\x0cuint64_value\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x30\n\x0bint32_value\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x32\n\x0cuint32_value\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12.\n\nbool_value\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0cstring_value\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\x0b\x62ytes_value\x18\t \x01(\x0b\x32\x1b.google.protobuf.BytesValue2`\n\x04Test\x12X\n\tgetOutput\x12$.googletypes_response_embedded.Input\x1a%.googletypes_response_embedded.Outputb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'googletypes_response_embedded_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_INPUT']._serialized_start=102
  _globals['_INPUT']._serialized_end=109
  _globals['_OUTPUT']._serialized_start=112
  _globals['_OUTPUT']._serialized_end=576
  _globals['_TEST']._serialized_start=578
  _globals['_TEST']._serialized_end=674
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: mapmessage.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "Test",
    "Nested",
)


from dataclasses import dataclass
from typing import (
    Dict,
)

import betterproto


@dataclass(eq=False, repr=False)
class Test(betterproto.Message):
    """ """

    items: Dict[str, "Nested"] = betterproto.map_field(
        1, betterproto.TYPE_STRING, betterproto.TYPE_MESSAGE
    )
    """
    
    """


@dataclass(eq=False, repr=False)
class Nested(betterproto.Message):
    """ """

    count: int = betterproto.int32_field(1)
    """
    
    """



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: oneof_enum.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "Signal",
    "Test",
    "Move",
)


from typing import (
    Optional,
)

from pydantic import model_validator
from pydantic.dataclasses import dataclass

import betterproto_fw


class Signal(betterproto_fw.Enum):
    """ """

    PASS = 0
    """
    
    """

    RESIGN = 1
    """
    
    """

    @classmethod
    def __get_pydantic_core_schema__(cls, _source_type, _handler):
        from pydantic_core import core_schema

        return core_schema.int_schema(ge=0)


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto_fw.Message):
    """ """

    signal: Optional["Signal"] = betterproto_fw.enum_field(
        1, optional=True, group="action"
    )
    """
    
    """

    move: Optional["Move"] = betterproto_fw.message_field(
        2, optional=True, group="action"
    )
    """
    
    """

    @model_validator(mode="after")
    def check_oneof(cls, values):
        return cls._validate_field_groups(values)


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Move(betterproto_fw.Message):
    """ """

    x: int = betterproto_fw.int32_field(1)
    """
    
    """

    y: int = betterproto_fw.int32_field(2)
    """
    
    """



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: messages.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'messages.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0emessages.proto\x12)service_separate_packages.things.messages\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x87\x01\n\x0e\x44oThingRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x63omments\x18\x02 \x03(\t\x12(\n\x04when\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x08\x64uration\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\" \n\x0f\x44oThingResponse\x12\r\n\x05names\x18\x01 \x03(\t\"\x1f\n\x0fGetThingRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"1\n\x10GetThingResponse\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'messages_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DOTHINGREQUEST']._serialized_start=127
  _globals['_DOTHINGREQUEST']._serialized_end=262
  _globals['_DOTHINGRESPONSE']._serialized_start=264
  _globals['_DOTHINGRESPONSE']._serialized_end=296
  _globals['_GETTHINGREQUEST']._serialized_start=298
  _globals['_GETTHINGREQUEST']._serialized_end=329
  _globals['_GETTHINGRESPONSE']._serialized_start=331
  _globals['_GETTHINGRESPONSE']._serialized_end=380
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: repeatedpacked.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from dataclasses import dataclass
from typing import (
    List,
)

import betterproto_fw


@dataclass(eq=False, repr=False)
class Test(betterproto_fw.Message):
    """ """

    counts: List[int] = betterproto_fw.int32_field(1)
    """
    
    """

    signed: List[int] = betterproto_fw.sint64_field(2)
    """
    
    """

    fixed: List[float] = betterproto_fw.double_field(3)
    """
    
    """



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: empty_repeated.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "MessageA",
    "Test",
)


from dataclasses import dataclass
from typing import (
    List,
)

import betterproto_fw


@dataclass(eq=False, repr=False)
class MessageA(betterproto_fw.Message):
    """ """

    values: List[float] = betterproto_fw.float_field(1)
    """
    
    """


@dataclass(eq=False, repr=False)
class Test(betterproto_fw.Message):
    """ """

    msg: List["MessageA"] = betterproto_fw.message_field(1)
    """
    
    """



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: namespace_keywords.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from pydantic.dataclasses import dataclass

import betterproto_fw


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto_fw.Message):
    """
    Tests that messages may contain fields that are Python keywords

    Generated with Python 3.7.6
    print('\n'.join(f'string {k} = {i+1};' for i,k in enumerate(keyword.kwlist)))
    """

    false: str = betterproto_fw.string_field(1)
    """
    
    """

    none: str = betterproto_fw.string_field(2)
    """
    
    """

    true: str = betterproto_fw.string_field(3)
    """
    
    """

    and_: str = betterproto_fw.string_field(4)
    """
    
    """

    as_: str = betterproto_fw.string_field(5)
    """
    
    """

    assert_: str = betterproto_fw.string_field(6)
    """
    
    """

    async_: str = betterproto_fw.string_field(7)
    """
    
    """

    await_: str = betterproto_fw.string_field(8)
    """
    
    """

    break_: str = betterproto_fw.string_field(9)
    """
    
    """

    class_: str = betterproto_fw.string_field(10)
    """
    
    """

    continue_: str = betterproto_fw.string_field(11)
    """
    
    """

    def_: str = betterproto_fw.string_field(12)
    """
    
    """

    del_: str = betterproto_fw.string_field(13)
    """
    
    """

    elif_: str = betterproto_fw.string_field(14)
    """
    
    """

    else_: str = betterproto_fw.string_field(15)
    """
    
    """

    except_: str = betterproto_fw.string_field(16)
    """
    
    """

    finally_: str = betterproto_fw.string_field(17)
    """
    
    """

    for_: str = betterproto_fw.string_field(18)
    """
    
    """

    from_: str = betterproto_fw.string_field(19)
    """
    
    """

    global_: str = betterproto_fw.string_field(20)
    """
    
    """

    if_: str = betterproto_fw.string_field(21)
    """
    
    """

    import_: str = betterproto_fw.string_field(22)
    """
    
    """

    in_: str = betterproto_fw.string_field(23)
    """
    
    """

    is_: str = betterproto_fw.string_field(24)
    """
    
    """

    lambda_: str = betterproto_fw.string_field(25)
    """
    
    """

    nonlocal_: str = betterproto_fw.string_field(26)
    """
    
    """

    not_: str = betterproto_fw.string_field(27)
    """
    
    """

    or_: str = betterproto_fw.string_field(28)
    """
    
    """

    pass_: str = betterproto_fw.string_field(29)
    """
    
    """

    raise_: str = betterproto_fw.string_field(30)
    """
    
    """

    return_: str = betterproto_fw.string_field(31)
    """
    
    """

    try_: str = betterproto_fw.string_field(32)
    """
    
    """

    while_: str = betterproto_fw.string_field(33)
    """
    
    """

    with_: str = betterproto_fw.string_field(34)
    """
    
    """

    yield_: str = betterproto_fw.string_field(35)
    """
    
    """



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: fixed.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False)
class Test(betterproto.Message):
    """ """

    foo: int = betterproto.fixed32_field(1)
    """
    
    """

    bar: int = betterproto.sfixed32_field(2)
    """
    
    """

    baz: int = betterproto.fixed64_field(3)
    """
    
    """

    qux: int = betterproto.sfixed64_field(4)
    """
    
    """



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: oneof_default_value_serialization.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "Message",
    "NestedMessage",
    "Test",
)


from dataclasses import dataclass
from datetime import datetime, timedelta
from typing import (
    Optional,
)

import betterproto_fw


@dataclass(eq=False, repr=False)
class Message(betterproto_fw.Message):
    """ """

    value: int = betterproto_fw.int64_field(1)
    """
    
    """


@dataclass(eq=False, repr=False)
class NestedMessage(betterproto_fw.Message):
    """ """

    id: int = betterproto_fw.int64_field(1)
    """
    
    """

    wrapped_message_value: "Message" = betterproto_fw.message_field(
        2, group="value_type"
    )
    """
    
    """


@dataclass(eq=False, repr=False)
class Test(betterproto_fw.Message):
    """ """

    bool_value: bool = betterproto_fw.bool_field(1, group="value_type")
    """
    
    """

    int64_value: int = betterproto_fw.int64_field(2, group="value_type")
    """
    
    """

    timestamp_value: datetime = betterproto_fw.message_field(3, group="value_type")
    """
    
    """

    duration_value: timedelta = betterproto_fw.message_field(4, group="value_type")
    """
    
    """

    wrapped_message_value: "Message" = betterproto_fw.message_field(
        5, group="value_type"
    )
    """
    
    """

    wrapped_nested_message_value: "NestedMessage" = betterproto_fw.message_field(
        6, group="value_type"
    )
    """
    
    """

    wrapped_bool_value: Optional[bool] = betterproto_fw.message_field(
        7, wraps=betterproto_fw.TYPE_BOOL, group="value_type"
    )
    """
    
    """



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: googletypes_service_returns_googletype.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "RequestMessage",
    "TestStub",
    "TestBase",
)


from typing import (
    TYPE_CHECKING,
    Dict,
    Optional,
)

import grpclib
from pydantic.dataclasses import dataclass

import betterproto
from betterproto.grpc.grpclib_server import ServiceBase


if TYPE_CHECKING:
    import grpclib.server
    from grpclib.metadata import Deadline

    from betterproto.grpc.grpclib_client import MetadataLike


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class RequestMessage(betterproto.Message):
    """ """

    pass


class TestStub(betterproto.ServiceStub):
    """
    Tests that imports are generated correctly when returning Google well-known types
    """

    async def get_empty(
        self,
        request_message: "RequestMessage",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "betterproto_lib_pydantic_google_protobuf.Empty":
        """ """

        return await self._unary_unary(
            "/googletypes_service_returns_googletype.Test/GetEmpty",
            request_message,
            betterproto_lib_pydantic_google_protobuf.Empty,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def get_struct(
        self,
        request_message: "RequestMessage",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "betterproto_lib_pydantic_google_protobuf.Struct":
        """ """

        return await self._unary_unary(
            "/googletypes_service_returns_googletype.Test/GetStruct",
            request_message,
            betterproto_lib_pydantic_google_protobuf.Struct,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def get_list_value(
        self,
        request_message: "RequestMessage",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "betterproto_lib_pydantic_google_protobuf.ListValue":
        """ """

        return await self._unary_unary(
            "/googletypes_service_returns_googletype.Test/GetListValue",
            request_message,
            betterproto_lib_pydantic_google_protobuf.ListValue,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def get_value(
        self,
        request_message: "RequestMessage",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "betterproto_lib_pydantic_google_protobuf.Value":
        """ """

        return await self._unary_unary(
            "/googletypes_service_returns_googletype.Test/GetValue",
            request_message,
            betterproto_lib_pydantic_google_protobuf.Value,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )


import betterproto.lib.pydantic.google.protobuf as betterproto_lib_pydantic_google_protobuf


class TestBase(ServiceBase):
    """
    Tests that imports are generated correctly when returning Google well-known types
    """

    async def get_empty(
        self, request_message: "RequestMessage"
    ) -> "betterproto_lib_pydantic_google_protobuf.Empty":
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def get_struct(
        self, request_message: "RequestMessage"
    ) -> "betterproto_lib_pydantic_google_protobuf.Struct":
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def get_list_value(
        self, request_message: "RequestMessage"
    ) -> "betterproto_lib_pydantic_google_protobuf.ListValue":
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def get_value(
        self, request_message: "RequestMessage"
    ) -> "betterproto_lib_pydantic_google_protobuf.Value":
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def __rpc_get_empty(
        self,
        stream: "grpclib.server.Stream[RequestMessage, betterproto_lib_pydantic_google_protobuf.Empty]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.get_empty(request)
        await stream.send_message(response)

    async def __rpc_get_struct(
        self,
        stream: "grpclib.server.Stream[RequestMessage, betterproto_lib_pydantic_google_protobuf.Struct]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.get_struct(request)
        await stream.send_message(response)

    async def __rpc_get_list_value(
        self,
        stream: "grpclib.server.Stream[RequestMessage, betterproto_lib_pydantic_google_protobuf.ListValue]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.get_list_value(request)
        await stream.send_message(response)

    async def __rpc_get_value(
        self,
        stream: "grpclib.server.Stream[RequestMessage, betterproto_lib_pydantic_google_protobuf.Value]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.get_value(request)
        await stream.send_message(response)

    def __mapping__(self) -> Dict[str, grpclib.const.Handler]:
        return {
            "/googletypes_service_returns_googletype.Test/GetEmpty": grpclib.const.Handler(
                self.__rpc_get_empty,
                grpclib.const.Cardinality.UNARY_UNARY,
                RequestMessage,
                betterproto_lib_pydantic_google_protobuf.Empty,
            ),
            "/googletypes_service_returns_googletype.Test/GetStruct": grpclib.const.Handler(
                self.__rpc_get_struct,
                grpclib.const.Cardinality.UNARY_UNARY,
                RequestMessage,
                betterproto_lib_pydantic_google_protobuf.Struct,
            ),
            "/googletypes_service_returns_googletype.Test/GetListValue": grpclib.const.Handler(
                self.__rpc_get_list_value,
                grpclib.const.Cardinality.UNARY_UNARY,
                RequestMessage,
                betterproto_lib_pydantic_google_protobuf.ListValue,
            ),
            "/googletypes_service_returns_googletype.Test/GetValue": grpclib.const.Handler(
                self.__rpc_get_value,
                grpclib.const.Cardinality.UNARY_UNARY,
                RequestMessage,
                betterproto_lib_pydantic_google_protobuf.Value,
            ),
        }



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: googletypes_struct.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from dataclasses import dataclass

import betterproto_fw


@dataclass(eq=False, repr=False)
class Test(betterproto_fw.Message):
    """ """

    struct: "betterproto_fw_lib_google_protobuf.Struct" = betterproto_fw.message_field(
        1
    )
    """
    
    """


import betterproto_fw.lib.google.protobuf as betterproto_fw_lib_google_protobuf



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: enum.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "Choice",
    "ArithmeticOperator",
    "Test",
)


from typing import (
    List,
)

from pydantic.dataclasses import dataclass

import betterproto


class Choice(betterproto.Enum):
    """ """

    ZERO = 0
    """
    
    """

    ONE = 1
    """
    
    """

    FOUR = 4
    """TWO = 2;"""

    THREE = 3
    """
    
    """

    @classmethod
    def __get_pydantic_core_schema__(cls, _source_type, _handler):
        from pydantic_core import core_schema

        return core_schema.int_schema(ge=0)


class ArithmeticOperator(betterproto.Enum):
    """
    A "C" like enum with the enum name prefixed onto members, these should be stripped
    """

    NONE = 0
    """
    
    """

    PLUS = 1
    """
    
    """

    MINUS = 2
    """
    
    """

    _0_PREFIXED = 3
    """
    
    """

    @classmethod
    def __get_pydantic_core_schema__(cls, _source_type, _handler):
        from pydantic_core import core_schema

        return core_schema.int_schema(ge=0)


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto.Message):
    """
    Tests that enums are correctly serialized and that it correctly handles skipped and out-of-order enum values
    """

    choice: "Choice" = betterproto.enum_field(1)
    """
    
    """

    choices: List["Choice"] = betterproto.enum_field(2)
    """
    
    """



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: namespace_builtin_types.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)

import builtins
from dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False)
class Test(betterproto.Message):
    """
    Tests that messages may contain fields with names that are python types
    """

    int: str = betterproto.string_field(1)
    """
    https://docs.python.org/2/library/stdtypes.html#numeric-types-int-float-long-complex
    """

    float: str = betterproto.string_field(2)
    """
    
    """

    complex: str = betterproto.string_field(3)
    """
    
    """

    list: str = betterproto.string_field(4)
    """
    https://docs.python.org/3/library/stdtypes.html#sequence-types-list-tuple-range
    """

    tuple: str = betterproto.string_field(5)
    """
    
    """

    range: str = betterproto.string_field(6)
    """
    
    """

    str: builtins.str = betterproto.string_field(7)
    """https://docs.python.org/3/library/stdtypes.html#str"""

    bytearray: builtins.str = betterproto.string_field(8)
    """https://docs.python.org/3/library/stdtypes.html#bytearray-objects"""

    bytes: builtins.str = betterproto.string_field(9)
    """
    https://docs.python.org/3/library/stdtypes.html#bytes-and-bytearray-operations
    """

    memoryview: builtins.str = betterproto.string_field(10)
    """https://docs.python.org/3/library/stdtypes.html#memory-views"""

    set: builtins.str = betterproto.string_field(11)
    """
    https://docs.python.org/3/library/stdtypes.html#set-types-set-frozenset
    """

    frozenset: builtins.str = betterproto.string_field(12)
    """
    
    """

    map: builtins.str = betterproto.string_field(13)
    """https://docs.python.org/3/library/stdtypes.html#dict"""

    dict: builtins.str = betterproto.string_field(14)
    """
    
    """

    bool: builtins.str = betterproto.string_field(15)
    """https://docs.python.org/3/library/stdtypes.html#boolean-values"""



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: googletypes.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from datetime import datetime, timedelta
from typing import (
    Optional,
)

from pydantic.dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto.Message):
    """ """

    maybe: Optional[bool] = betterproto.message_field(1, wraps=betterproto.TYPE_BOOL)
    """
    
    """

    ts: datetime = betterproto.message_field(2)
    """
    
    """

    duration: timedelta = betterproto.message_field(3)
    """
    
    """

    important: Optional[int] = betterproto.message_field(
        4, wraps=betterproto.TYPE_INT32
    )
    """
    
    """

    empty: "betterproto_lib_pydantic_google_protobuf.Empty" = betterproto.message_field(
        5
    )
    """
    
    """


import betterproto.lib.pydantic.google.protobuf as betterproto_lib_pydantic_google_protobuf



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: root.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("RootMessage",)


from dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False)
class RootMessage(betterproto.Message):
    """ """

    pass



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: child_package_request_message.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("ChildRequestMessage",)


from dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False)
class ChildRequestMessage(betterproto.Message):
    """ """

    child_argument: int = betterproto.int32_field(1)
    """
    
    """



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nested.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'nested.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cnested.proto\x12\x06nested\"\xc3\x01\n\x04Test\x12#\n\x06nested\x18\x01 \x01(\x0b\x32\x13.nested.Test.Nested\x12 \n\x07sibling\x18\x02 \x01(\x0b\x32\x0f.nested.Sibling\x12!\n\x08sibling2\x18\x03 \x01(\x0b\x32\x0f.nested.Sibling\x12\x1d\n\x03msg\x18\x04 \x01(\x0e\x32\x10.nested.Test.Msg\x1a\x17\n\x06Nested\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\"\x19\n\x03Msg\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04THIS\x10\x01\"\x16\n\x07Sibling\x12\x0b\n\x03\x66oo\x18\x01 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nested_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TEST']._serialized_start=25
  _globals['_TEST']._serialized_end=220
  _globals['_TEST_NESTED']._serialized_start=170
  _globals['_TEST_NESTED']._serialized_end=193
  _globals['_TEST_MSG']._serialized_start=195
  _globals['_TEST_MSG']._serialized_end=220
  _globals['_SIBLING']._serialized_start=222
  _globals['_SIBLING']._serialized_end=244
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: proto3_field_presence_oneof.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "Test",
    "InnerNested",
    "Nested",
    "WithOptional",
)


from typing import (
    Optional,
)

from pydantic import model_validator
from pydantic.dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto.Message):
    """ """

    nested: Optional["Nested"] = betterproto.message_field(
        1, optional=True, group="kind"
    )
    """
    
    """

    with_optional: Optional["WithOptional"] = betterproto.message_field(
        2, optional=True, group="kind"
    )
    """
    
    """

    @model_validator(mode="after")
    def check_oneof(cls, values):
        return cls._validate_field_groups(values)


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class InnerNested(betterproto.Message):
    """ """

    a: Optional[bool] = betterproto.bool_field(1, optional=True)
    """
    
    """


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Nested(betterproto.Message):
    """ """

    inner: "InnerNested" = betterproto.message_field(1)
    """
    
    """


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class WithOptional(betterproto.Message):
    """ """

    b: Optional[bool] = betterproto.bool_field(2, optional=True)
    """
    
    """



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: nestedtwice.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "TestTopMiddleEnumBottom",
    "Test",
    "TestTop",
    "TestTopMiddle",
    "TestTopMiddleTopMiddleBottom",
    "TestTopMiddleBottom",
)


from typing import (
    List,
)

from pydantic.dataclasses import dataclass

import betterproto


class TestTopMiddleEnumBottom(betterproto.Enum):
    """EnumBottom doc."""

    A = 0
    """EnumBottom.A doc. """

    B = 1
    """
    
    """

    @classmethod
    def __get_pydantic_core_schema__(cls, _source_type, _handler):
        from pydantic_core import core_schema

        return core_schema.int_schema(ge=0)


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto.Message):
    """Test doc."""

    top: "TestTop" = betterproto.message_field(1)
    """Test.top doc. """


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class TestTop(betterproto.Message):
    """Top doc."""

    name: str = betterproto.string_field(1)
    """Top.name doc. """

    middle: "TestTopMiddle" = betterproto.message_field(2)
    """
    
    """


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class TestTopMiddle(betterproto.Message):
    """Middle doc."""

    bottom: List["TestTopMiddleBottom"] = betterproto.message_field(2)
    """Middle.bottom doc. """

    enum_bottom: List["TestTopMiddleEnumBottom"] = betterproto.enum_field(3)
    """
    
    """

    top_middle_bottom: List["TestTopMiddleTopMiddleBottom"] = betterproto.message_field(
        4
    )
    """
    
    """

    bar: bool = betterproto.bool_field(5)
    """
    
    """


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class TestTopMiddleTopMiddleBottom(betterproto.Message):
    """TopMiddleBottom doc."""

    a: str = betterproto.string_field(1)
    """TopMiddleBottom.a doc."""


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class TestTopMiddleBottom(betterproto.Message):
    """Bottom doc."""

    foo: str = betterproto.string_field(1)
    """Bottom.foo doc. """



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: example.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'example.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rexample.proto\x12\x07\x65xample\"?\n\x11\x46ileDescriptorSet\x12*\n\x04\x66ile\x18\x01 \x03(\x0b\x32\x1c.example.FileDescriptorProto\"\xab\x03\n\x13\x46ileDescriptorProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07package\x18\x02 \x01(\t\x12\x12\n\ndependency\x18\x03 \x03(\t\x12\x19\n\x11public_dependency\x18\n \x03(\x05\x12\x17\n\x0fweak_dependency\x18\x0b \x03(\x05\x12.\n\x0cmessage_type\x18\x04 \x03(\x0b\x32\x18.example.DescriptorProto\x12/\n\tenum_type\x18\x05 \x03(\x0b\x32\x1c.example.EnumDescriptorProto\x12\x30\n\x07service\x18\x06 \x03(\x0b\x32\x1f.example.ServiceDescriptorProto\x12\x30\n\textension\x18\x07 \x03(\x0b\x32\x1d.example.FieldDescriptorProto\x12%\n\x07options\x18\x08 \x01(\x0b\x32\x14.example.FileOptions\x12\x31\n\x10source_code_info\x18\t \x01(\x0b\x32\x17.example.SourceCodeInfo\x12\x0e\n\x06syntax\x18\x0c \x01(\t\"\xe1\x04\n\x0f\x44\x65scriptorProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12,\n\x05\x66ield\x18\x02 \x03(\x0b\x32\x1d.example.FieldDescriptorProto\x12\x30\n\textension\x18\x06 \x03(\x0b\x32\x1d.example.FieldDescriptorProto\x12-\n\x0bnested_type\x18\x03 \x03(\x0b\x32\x18.example.DescriptorProto\x12/\n\tenum_type\x18\x04 \x03(\x0b\x32\x1c.example.EnumDescriptorProto\x12@\n\x0f\x65xtension_range\x18\x05 \x03(\x0b\x32\'.example.DescriptorProto.ExtensionRange\x12\x31\n\noneof_decl\x18\x08 \x03(\x0b\x32\x1d.example.OneofDescriptorProto\x12(\n\x07options\x18\x07 \x01(\x0b\x32\x17.example.MessageOptions\x12>\n\x0ereserved_range\x18\t \x03(\x0b\x32&.example.DescriptorProto.ReservedRange\x12\x15\n\rreserved_name\x18\n \x03(\t\x1a]\n\x0e\x45xtensionRange\x12\r\n\x05start\x18\x01 \x01(\x05\x12\x0b\n\x03\x65nd\x18\x02 \x01(\x05\x12/\n\x07options\x18\x03 \x01(\x0b\x32\x1e.example.ExtensionRangeOptions\x1a+\n\rReservedRange\x12\r\n\x05start\x18\x01 \x01(\x05\x12\x0b\n\x03\x65nd\x18\x02 \x01(\x05\"_\n\x15\x45xtensionRangeOptions\x12;\n\x14uninterpreted_option\x18\xe7\x07 \x03(\x0b\x32\x1c.example.UninterpretedOption*\t\x08\xe8\x07\x10\x80\x80\x80\x80\x02\"\xbd\x05\n\x14\x46ieldDescriptorProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06number\x18\x03 \x01(\x05\x12\x32\n\x05label\x18\x04 \x01(\x0e\x32#.example.FieldDescriptorProto.Label\x12\x30\n\x04type\x18\x05 \x01(\x0e\x32\".example.FieldDescriptorProto.Type\x12\x11\n\ttype_name\x18\x06 \x01(\t\x12\x10\n\x08\x65xtendee\x18\x02 \x01(\t\x12\x15\n\rdefault_value\x18\x07 \x01(\t\x12\x13\n\x0boneof_index\x18\t \x01(\x05\x12\x11\n\tjson_name\x18\n \x01(\t\x12&\n\x07options\x18\x08 \x01(\x0b\x32\x15.example.FieldOptions\x12\x17\n\x0fproto3_optional\x18\x11 \x01(\x08\"\xb6\x02\n\x04Type\x12\x0f\n\x0bTYPE_DOUBLE\x10\x01\x12\x0e\n\nTYPE_FLOAT\x10\x02\x12\x0e\n\nTYPE_INT64\x10\x03\x12\x0f\n\x0bTYPE_UINT64\x10\x04\x12\x0e\n\nTYPE_INT32\x10\x05\x12\x10\n\x0cTYPE_FIXED64\x10\x06\x12\x10\n\x0cTYPE_FIXED32\x10\x07\x12\r\n\tTYPE_BOOL\x10\x08\x12\x0f\n\x0bTYPE_STRING\x10\t\x12\x0e\n\nTYPE_GROUP\x10\n\x12\x10\n\x0cTYPE_MESSAGE\x10\x0b\x12\x0e\n\nTYPE_BYTES\x10\x0c\x12\x0f\n\x0bTYPE_UINT32\x10\r\x12\r\n\tTYPE_ENUM\x10\x0e\x12\x11\n\rTYPE_SFIXED32\x10\x0f\x12\x11\n\rTYPE_SFIXED64\x10\x10\x12\x0f\n\x0bTYPE_SINT32\x10\x11\x12\x0f\n\x0bTYPE_SINT64\x10\x12\"C\n\x05Label\x12\x12\n\x0eLABEL_OPTIONAL\x10\x01\x12\x12\n\x0eLABEL_REQUIRED\x10\x02\x12\x12\n\x0eLABEL_REPEATED\x10\x03\"L\n\x14OneofDescriptorProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12&\n\x07options\x18\x02 \x01(\x0b\x32\x15.example.OneofOptions\"\x8c\x02\n\x13\x45numDescriptorProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x30\n\x05value\x18\x02 \x03(\x0b\x32!.example.EnumValueDescriptorProto\x12%\n\x07options\x18\x03 \x01(\x0b\x32\x14.example.EnumOptions\x12\x46\n\x0ereserved_range\x18\x04 \x03(\x0b\x32..example.EnumDescriptorProto.EnumReservedRange\x12\x15\n\rreserved_name\x18\x05 \x03(\t\x1a/\n\x11\x45numReservedRange\x12\r\n\x05start\x18\x01 \x01(\x05\x12\x0b\n\x03\x65nd\x18\x02 \x01(\x05\"d\n\x18\x45numValueDescriptorProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06number\x18\x02 \x01(\x05\x12*\n\x07options\x18\x03 \x01(\x0b\x32\x19.example.EnumValueOptions\"\x80\x01\n\x16ServiceDescriptorProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\x06method\x18\x02 \x03(\x0b\x32\x1e.example.MethodDescriptorProto\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.example.ServiceOptions\"\xb9\x01\n\x15MethodDescriptorProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ninput_type\x18\x02 \x01(\t\x12\x13\n\x0boutput_type\x18\x03 \x01(\t\x12\'\n\x07options\x18\x04 \x01(\x0b\x32\x16.example.MethodOptions\x12\x1f\n\x10\x63lient_streaming\x18\x05 \x01(\x08:\x05\x66\x61lse\x12\x1f\n\x10server_streaming\x18\x06 \x01(\x08:\x05\x66\x61lse\"\x95\x06\n\x0b\x46ileOptions\x12\x14\n\x0cjava_package\x18\x01 \x01(\t\x12\x1c\n\x14java_outer_classname\x18\x08 \x01(\t\x12\"\n\x13java_multiple_files\x18\n \x01(\x08:\x05\x66\x61lse\x12)\n\x1djava_generate_equals_and_hash\x18\x14 \x01(\x08\x42\x02\x18\x01\x12%\n\x16java_string_check_utf8\x18\x1b \x01(\x08:\x05\x66\x61lse\x12>\n\x0coptimize_for\x18\t \x01(\x0e\x32!.example.FileOptions.OptimizeMode:\x05SPEED\x12\x12\n\ngo_package\x18\x0b \x01(\t\x12\"\n\x13\x63\x63_generic_services\x18\x10 \x01(\x08:\x05\x66\x61lse\x12$\n\x15java_generic_services\x18\x11 \x01(\x08:\x05\x66\x61lse\x12\"\n\x13py_generic_services\x18\x12 \x01(\x08:\x05\x66\x61lse\x12#\n\x14php_generic_services\x18* \x01(\x08:\x05\x66\x61lse\x12\x19\n\ndeprecated\x18\x17 \x01(\x08:\x05\x66\x61lse\x12\x1e\n\x10\x63\x63_enable_arenas\x18\x1f \x01(\x08:\x04true\x12\x19\n\x11objc_class_prefix\x18$ \x01(\t\x12\x18\n\x10\x63sharp_namespace\x18% \x01(\t\x12\x14\n\x0cswift_prefix\x18\' \x01(\t\x12\x18\n\x10php_class_prefix\x18( \x01(\t\x12\x15\n\rphp_namespace\x18) \x01(\t\x12\x1e\n\x16php_metadata_namespace\x18, \x01(\t\x12\x14\n\x0cruby_package\x18- \x01(\t\x12;\n\x14uninterpreted_option\x18\xe7\x07 \x03(\x0b\x32\x1c.example.UninterpretedOption\":\n\x0cOptimizeMode\x12\t\n\x05SPEED\x10\x01\x12\r\n\tCODE_SIZE\x10\x02\x12\x10\n\x0cLITE_RUNTIME\x10\x03*\t\x08\xe8\x07\x10\x80\x80\x80\x80\x02J\x04\x08&\x10\'\"\xea\x01\n\x0eMessageOptions\x12&\n\x17message_set_wire_format\x18\x01 \x01(\x08:\x05\x66\x61lse\x12.\n\x1fno_standard_descriptor_accessor\x18\x02 \x01(\x08:\x05\x66\x61lse\x12\x19\n\ndeprecated\x18\x03 \x01(\x08:\x05\x66\x61lse\x12\x11\n\tmap_entry\x18\x07 \x01(\x08\x12;\n\x14uninterpreted_option\x18\xe7\x07 \x03(\x0b\x32\x1c.example.UninterpretedOption*\t\x08\xe8\x07\x10\x80\x80\x80\x80\x02J\x04\x08\x08\x10\tJ\x04\x08\t\x10\n\"\x86\x03\n\x0c\x46ieldOptions\x12\x32\n\x05\x63type\x18\x01 \x01(\x0e\x32\x1b.example.FieldOptions.CType:\x06STRING\x12\x0e\n\x06packed\x18\x02 \x01(\x08\x12\x37\n\x06jstype\x18\x06 \x01(\x0e\x32\x1c.example.FieldOptions.JSType:\tJS_NORMAL\x12\x13\n\x04lazy\x18\x05 \x01(\x08:\x05\x66\x61lse\x12\x19\n\ndeprecated\x18\x03 \x01(\x08:\x05\x66\x61lse\x12\x13\n\x04weak\x18\n \x01(\x08:\x05\x66\x61lse\x12;\n\x14uninterpreted_option\x18\xe7\x07 \x03(\x0b\x32\x1c.example.UninterpretedOption\"/\n\x05\x43Type\x12\n\n\x06STRING\x10\x00\x12\x08\n\x04\x43ORD\x10\x01\x12\x10\n\x0cSTRING_PIECE\x10\x02\"5\n\x06JSType\x12\r\n\tJS_NORMAL\x10\x00\x12\r\n\tJS_STRING\x10\x01\x12\r\n\tJS_NUMBER\x10\x02*\t\x08\xe8\x07\x10\x80\x80\x80\x80\x02J\x04\x08\x04\x10\x05\"V\n\x0cOneofOptions\x12;\n\x14uninterpreted_option\x18\xe7\x07 \x03(\x0b\x32\x1c.example.UninterpretedOption*\t\x08\xe8\x07\x10\x80\x80\x80\x80\x02\"\x8b\x01\n\x0b\x45numOptions\x12\x13\n\x0b\x61llow_alias\x18\x02 \x01(\x08\x12\x19\n\ndeprecated\x18\x03 \x01(\x08:\x05\x66\x61lse\x12;\n\x14uninterpreted_option\x18\xe7\x07 \x03(\x0b\x32\x1c.example.UninterpretedOption*\t\x08\xe8\x07\x10\x80\x80\x80\x80\x02J\x04\x08\x05\x10\x06\"u\n\x10\x45numValueOptions\x12\x19\n\ndeprecated\x18\x01 \x01(\x08:\x05\x66\x61lse\x12;\n\x14uninterpreted_option\x18\xe7\x07 \x03(\x0b\x32\x1c.example.UninterpretedOption*\t\x08\xe8\x07\x10\x80\x80\x80\x80\x02\"s\n\x0eServiceOptions\x12\x19\n\ndeprecated\x18! \x01(\x08:\x05\x66\x61lse\x12;\n\x14uninterpreted_option\x18\xe7\x07 \x03(\x0b\x32\x1c.example.UninterpretedOption*\t\x08\xe8\x07\x10\x80\x80\x80\x80\x02\"\x9d\x02\n\rMethodOptions\x12\x19\n\ndeprecated\x18! \x01(\x08:\x05\x66\x61lse\x12W\n\x11idempotency_level\x18\" \x01(\x0e\x32\'.example.MethodOptions.IdempotencyLevel:\x13IDEMPOTENCY_UNKNOWN\x12;\n\x14uninterpreted_option\x18\xe7\x07 \x03(\x0b\x32\x1c.example.UninterpretedOption\"P\n\x10IdempotencyLevel\x12\x17\n\x13IDEMPOTENCY_UNKNOWN\x10\x00\x12\x13\n\x0fNO_SIDE_EFFECTS\x10\x01\x12\x0e\n\nIDEMPOTENT\x10\x02*\t\x08\xe8\x07\x10\x80\x80\x80\x80\x02\"\x96\x02\n\x13UninterpretedOption\x12\x33\n\x04name\x18\x02 \x03(\x0b\x32%.example.UninterpretedOption.NamePart\x12\x18\n\x10identifier_value\x18\x03 \x01(\t\x12\x1a\n\x12positive_int_value\x18\x04 \x01(\x04\x12\x1a\n\x12negative_int_value\x18\x05 \x01(\x03\x12\x14\n\x0c\x64ouble_value\x18\x06 \x01(\x01\x12\x14\n\x0cstring_value\x18\x07 \x01(\x0c\x12\x17\n\x0f\x61ggregate_value\x18\x08 \x01(\t\x1a\x33\n\x08NamePart\x12\x11\n\tname_part\x18\x01 \x02(\t\x12\x14\n\x0cis_extension\x18\x02 \x02(\x08\"\xcd\x01\n\x0eSourceCodeInfo\x12\x32\n\x08location\x18\x01 \x03(\x0b\x32 .example.SourceCodeInfo.Location\x1a\x86\x01\n\x08Location\x12\x10\n\x04path\x18\x01 \x03(\x05\x42\x02\x10\x01\x12\x10\n\x04span\x18\x02 \x03(\x05\x42\x02\x10\x01\x12\x18\n\x10leading_comments\x18\x03 \x01(\t\x12\x19\n\x11trailing_comments\x18\x04 \x01(\t\x12!\n\x19leading_detached_comments\x18\x06 \x03(\t\"\x9f\x01\n\x11GeneratedCodeInfo\x12\x39\n\nannotation\x18\x01 \x03(\x0b\x32%.example.GeneratedCodeInfo.Annotation\x1aO\n\nAnnotation\x12\x10\n\x04path\x18\x01 \x03(\x05\x42\x02\x10\x01\x12\x13\n\x0bsource_file\x18\x02 \x01(\t\x12\r\n\x05\x62\x65gin\x18\x03 \x01(\x05\x12\x0b\n\x03\x65nd\x18\x04 \x01(\x05\x42~\n\x13\x63om.google.protobufB\x10\x44\x65scriptorProtosH\x01Z-google.golang.org/protobuf/types/descriptorpb\xf8\x01\x01\xa2\x02\x03GPB\xaa\x02\x1aGoogle.Protobuf.Reflection')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'example_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023com.google.protobufB\020DescriptorProtosH\001Z-google.golang.org/protobuf/types/descriptorpb\370\001\001\242\002\003GPB\252\002\032Google.Protobuf.Reflection'
  _globals['_FILEOPTIONS'].fields_by_name['java_generate_equals_and_hash']._loaded_options = None
  _globals['_FILEOPTIONS'].fields_by_name['java_generate_equals_and_hash']._serialized_options = b'\030\001'
  _globals['_SOURCECODEINFO_LOCATION'].fields_by_name['path']._loaded_options = None
  _globals['_SOURCECODEINFO_LOCATION'].fields_by_name['path']._serialized_options = b'\020\001'
  _globals['_SOURCECODEINFO_LOCATION'].fields_by_name['span']._loaded_options = None
  _globals['_SOURCECODEINFO_LOCATION'].fields_by_name['span']._serialized_options = b'\020\001'
  _globals['_GENERATEDCODEINFO_ANNOTATION'].fields_by_name['path']._loaded_options = None
  _globals['_GENERATEDCODEINFO_ANNOTATION'].fields_by_name['path']._serialized_options = b'\020\001'
  _globals['_FILEDESCRIPTORSET']._serialized_start=26
  _globals['_FILEDESCRIPTORSET']._serialized_end=89
  _globals['_FILEDESCRIPTORPROTO']._serialized_start=92
  _globals['_FILEDESCRIPTORPROTO']._serialized_end=519
  _globals['_DESCRIPTORPROTO']._serialized_start=522
  _globals['_DESCRIPTORPROTO']._serialized_end=1131
  _globals['_DESCRIPTORPROTO_EXTENSIONRANGE']._serialized_start=993
  _globals['_DESCRIPTORPROTO_EXTENSIONRANGE']._serialized_end=1086
  _globals['_DESCRIPTORPROTO_RESERVEDRANGE']._serialized_start=1088
  _globals['_DESCRIPTORPROTO_RESERVEDRANGE']._serialized_end=1131
  _globals['_EXTENSIONRANGEOPTIONS']._serialized_start=1133
  _globals['_EXTENSIONRANGEOPTIONS']._serialized_end=1228
  _globals['_FIELDDESCRIPTORPROTO']._serialized_start=1231
  _globals['_FIELDDESCRIPTORPROTO']._serialized_end=1932
  _globals['_FIELDDESCRIPTORPROTO_TYPE']._serialized_start=1553
  _globals['_FIELDDESCRIPTORPROTO_TYPE']._serialized_end=1863
  _globals['_FIELDDESCRIPTORPROTO_LABEL']._serialized_start=1865
  _globals['_FIELDDESCRIPTORPROTO_LABEL']._serialized_end=1932
  _globals['_ONEOFDESCRIPTORPROTO']._serialized_start=1934
  _globals['_ONEOFDESCRIPTORPROTO']._serialized_end=2010
  _globals['_ENUMDESCRIPTORPROTO']._serialized_start=2013
  _globals['_ENUMDESCRIPTORPROTO']._serialized_end=2281
  _globals['_ENUMDESCRIPTORPROTO_ENUMRESERVEDRANGE']._serialized_start=2234
  _globals['_ENUMDESCRIPTORPROTO_ENUMRESERVEDRANGE']._serialized_end=2281
  _globals['_ENUMVALUEDESCRIPTORPROTO']._serialized_start=2283
  _globals['_ENUMVALUEDESCRIPTORPROTO']._serialized_end=2383
  _globals['_SERVICEDESCRIPTORPROTO']._serialized_start=2386
  _globals['_SERVICEDESCRIPTORPROTO']._serialized_end=2514
  _globals['_METHODDESCRIPTORPROTO']._serialized_start=2517
  _globals['_METHODDESCRIPTORPROTO']._serialized_end=2702
  _globals['_FILEOPTIONS']._serialized_start=2705
  _globals['_FILEOPTIONS']._serialized_end=3494
  _globals['_FILEOPTIONS_OPTIMIZEMODE']._serialized_start=3419
  _globals['_FILEOPTIONS_OPTIMIZEMODE']._serialized_end=3477
  _globals['_MESSAGEOPTIONS']._serialized_start=3497
  _globals['_MESSAGEOPTIONS']._serialized_end=3731
  _globals['_FIELDOPTIONS']._serialized_start=3734
  _globals['_FIELDOPTIONS']._serialized_end=4124
  _globals['_FIELDOPTIONS_CTYPE']._serialized_start=4005
  _globals['_FIELDOPTIONS_CTYPE']._serialized_end=4052
  _globals['_FIELDOPTIONS_JSTYPE']._serialized_start=4054
  _globals['_FIELDOPTIONS_JSTYPE']._serialized_end=4107
  _globals['_ONEOFOPTIONS']._serialized_start=4126
  _globals['_ONEOFOPTIONS']._serialized_end=4212
  _globals['_ENUMOPTIONS']._serialized_start=4215
  _globals['_ENUMOPTIONS']._serialized_end=4354
  _globals['_ENUMVALUEOPTIONS']._serialized_start=4356
  _globals['_ENUMVALUEOPTIONS']._serialized_end=4473
  _globals['_SERVICEOPTIONS']._serialized_start=4475
  _globals['_SERVICEOPTIONS']._serialized_end=4590
  _globals['_METHODOPTIONS']._serialized_start=4593
  _globals['_METHODOPTIONS']._serialized_end=4878
  _globals['_METHODOPTIONS_IDEMPOTENCYLEVEL']._serialized_start=4787
  _globals['_METHODOPTIONS_IDEMPOTENCYLEVEL']._serialized_end=4867
  _globals['_UNINTERPRETEDOPTION']._serialized_start=4881
  _globals['_UNINTERPRETEDOPTION']._serialized_end=5159
  _globals['_UNINTERPRETEDOPTION_NAMEPART']._serialized_start=5108
  _globals['_UNINTERPRETEDOPTION_NAMEPART']._serialized_end=5159
  _globals['_SOURCECODEINFO']._serialized_start=5162
  _globals['_SOURCECODEINFO']._serialized_end=5367
  _globals['_SOURCECODEINFO_LOCATION']._serialized_start=5233
  _globals['_SOURCECODEINFO_LOCATION']._serialized_end=5367
  _globals['_GENERATEDCODEINFO']._serialized_start=5370
  _globals['_GENERATEDCODEINFO']._serialized_end=5529
  _globals['_GENERATEDCODEINFO_ANNOTATION']._serialized_start=5450
  _globals['_GENERATEDCODEINFO_ANNOTATION']._serialized_end=5529
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: ref.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from pydantic.dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto.Message):
    """ """

    greeting: "_repeatedmessage__.Sub" = betterproto.message_field(1)
    """
    
    """


from .. import repeatedmessage as _repeatedmessage__



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: recursivemessage.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "Test",
    "Intermediate",
)


from pydantic.dataclasses import dataclass

import betterproto_fw


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto_fw.Message):
    """ """

    name: str = betterproto_fw.string_field(1)
    """
    
    """

    child: "Test" = betterproto_fw.message_field(2)
    """
    
    """

    intermediate: "Intermediate" = betterproto_fw.message_field(3)
    """
    
    """


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Intermediate(betterproto_fw.Message):
    """ """

    number: int = betterproto_fw.int32_field(1)
    """
    
    """

    child: "Test" = betterproto_fw.message_field(2)
    """
    
    """



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: proto3_field_presence.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "TestEnum",
    "InnerTest",
    "Test",
)


from dataclasses import dataclass
from datetime import datetime
from typing import (
    Optional,
)

import betterproto_fw


class TestEnum(betterproto_fw.Enum):
    """ """

    A = 0
    """
    
    """

    B = 1
    """
    
    """


@dataclass(eq=False, repr=False)
class InnerTest(betterproto_fw.Message):
    """ """

    test: str = betterproto_fw.string_field(1)
    """
    
    """


@dataclass(eq=False, repr=False)
class Test(betterproto_fw.Message):
    """ """

    test1: Optional[int] = betterproto_fw.uint32_field(1, optional=True)
    """
    
    """

    test2: Optional[bool] = betterproto_fw.bool_field(2, optional=True)
    """
    
    """

    test3: Optional[str] = betterproto_fw.string_field(3, optional=True)
    """
    
    """

    test4: Optional[bytes] = betterproto_fw.bytes_field(4, optional=True)
    """
    
    """

    test5: Optional["InnerTest"] = betterproto_fw.message_field(5, optional=True)
    """
    
    """

    test6: Optional["TestEnum"] = betterproto_fw.enum_field(6, optional=True)
    """
    
    """

    test7: Optional[int] = betterproto_fw.uint64_field(7, optional=True)
    """
    
    """

    test8: Optional[float] = betterproto_fw.float_field(8, optional=True)
    """
    
    """

    test9: Optional[datetime] = betterproto_fw.message_field(9, optional=True)
    """
    
    """



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: test.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from pydantic.dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto.Message):
    """Verify that we can import message unrelated to us"""

    message: "__cousin_cousin_subpackage__.CousinMessage" = betterproto.message_field(1)
    """
    
    """


from ...cousin import cousin_subpackage as __cousin_cousin_subpackage__
